@@ -225,7 +225,7 @@ static int parseSAct(PARSER* Pdf, int cState, int cTok)
       CFG_COM(Pdf->Tab->Kfg->TokKind[cTok])     ) return( PLR_SHIFT_NONE );
   if( PLR_MSHIFT[cState] == PLR_SHIFT_ERROR )     return( PLR_SHIFT_ERROR );
   for( i = PLR_MSHIFT[cState], j = i-1; 
-       PLR_DSHIFT[i] >= 0 && i < PLR_DSHIFTCNT; ++i, --j )
+       i < PLR_DSHIFTCNT && PLR_DSHIFT[i] >= 0; ++i, --j )
     if( PLR_DSHIFT[i] == cTok ) return( ABS(PLR_DSHIFT[j]) - 1 );
   return( PLR_SHIFT_ERROR );
 }
@@ -240,7 +240,7 @@ static int parseRAct(PARSER* Pdf, int cState, int cTok)
         e_first = PLR_ACTE[i], 
         act     = PLR_ACT_ERROR, e_entry;
 
-    for( ; EQSIGN(e_first,PLR_ACTE[i]) && i < PLR_ACTECNT; ++i )
+    for( ; i < PLR_ACTECNT && EQSIGN(e_first,PLR_ACTE[i]); ++i )
     {
       if( ( e_entry = ABS(PLR_ACTE[i]) ) > PLR_PROD_OFFSET )
         act = e_entry - PLR_PROD_OFFSET;
@@ -824,6 +824,15 @@ string PLR_language(PLR_Tab PTab)
   return( PLR_T_IMP(PTab)->Kfg->language );
 }
 
+int PLR_conflictCnt(PLR_Tab PTab)
+/* number of conflicts of parse table 'PTab';
+   available only after construction
+*/
+{
+  BUG_NULL(PTab);
+  return( PLR_T_IMP(PTab)->Conflicts );
+}
+
 int PLR_tokenCnt(PLR_Tab PTab)
 /* number of tokens of parse table 'PTab' */
 {
@@ -1118,7 +1127,7 @@ ROW(int) PLR_actionValues(PLR_Tab PTab, int stateId)
       i       = ABS(entry);
       e_first = actexp[i];
       action  = -2;
-      for( ; EQSIGN(e_first,actexp[i]) && i < cnt_actexp; ++i )
+      for( ; i < cnt_actexp && EQSIGN(e_first,actexp[i]); ++i )
       {
         if( ( e_entry = ABS(actexp[i]) ) > prodoffset )
         {
