@@ -12,6 +12,7 @@
 #include "pathes.h"
 #include "literal.h"
 #include "sink.h"
+#include "line_scn.h"
 
 /*!!
    This module provides functions that 
@@ -484,120 +485,211 @@ void PLR_CTab_Modul(string Environ, PLR_Tab PTab, c_bool shortform)
   FreeMem(fid);
 }
 
-void PLR_Src_Source(FILE* fp, c_string fid, PLR_Tab PTab)
+void PLR_Src_Source
+     (
+       FILE* fp, c_string fid, PLR_Tab PTab, c_string prefix, c_string suffix
+     )
 /* writes source for parse table 'PTab' to file 'fp';
-   produces a source header if filename 'fid' is not empty
+   produces a source header if filename 'fid' is not empty;
+   encapsulates output lines with 'prefix' and 'suffix'
 */
 { int cnt, scnt, i, j;
+  c_string nl = ( !STR_EMPTY(prefix) && !STR_EMPTY(suffix) ) ? "\\n" : "";
   if( !STR_EMPTY(fid) )
     fprintf
     (
-      fp,"# [%s] Parser table for '%s'\n\n", 
-      fid, PLR_T_IMP(PTab)->Kfg->language
+      fp,"%s# [%s] Parser table for '%s'%s%s%s\n\n", 
+      prefix, fid, PLR_T_IMP(PTab)->Kfg->language, nl, nl, suffix
     );
-  fprintf(fp,"# CFG Definition\n\nKFGHEAD\n");
-  fprintf(fp,"Name=%s\n",PLR_T_IMP(PTab)->Kfg->language);
-  fprintf(fp,"TkCnt=%d\n",PLR_T_IMP(PTab)->Kfg->TkCnt);
-  fprintf(fp,"NtCnt=%d\n",PLR_T_IMP(PTab)->Kfg->NtCnt);
-  fprintf(fp,"SNames\n");
+  fprintf
+  (
+    fp,"%s# CFG Definition%s%s%s\n\n%sKFGHEAD%s%s\n",
+    prefix,nl,nl,suffix,prefix,nl,suffix
+  );
+  fprintf(fp,"%sName=%s%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->language,nl,suffix);
+  fprintf(fp,"%sTkCnt=%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->TkCnt,nl,suffix);
+  fprintf(fp,"%sNtCnt=%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->NtCnt,nl,suffix);
+  fprintf(fp,"%sSNames%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->Kfg->TkCnt + PLR_T_IMP(PTab)->Kfg->NtCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp," %s\n",PLR_T_IMP(PTab)->Kfg->SNames[i]);
+    if( strlen(nl) > 0 )
+    { c_string t = LIT_c_str_lit(PLR_T_IMP(PTab)->Kfg->SNames[i]);
+      fprintf
+      (
+        fp,"%s %s%s%s\n", prefix,t,nl,suffix
+      );
+      FreeMem(t);
+    }
+    else
+      fprintf(fp," %s\n",PLR_T_IMP(PTab)->Kfg->SNames[i]);
   }
-  fprintf(fp,"StartIds\n");
+  fprintf(fp,"%sStartIds%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->Kfg->StartCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Kfg->StartIds[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->StartIds[i],nl,suffix
+    );
   }
-  fprintf(fp,"TokKind\n");
-  cnt = PLR_T_IMP(PTab)->Kfg->TkCnt + PLR_T_IMP(PTab)->Kfg->NtCnt;
+  fprintf(fp,"%sTokKind%s%s\n",prefix,nl,suffix);
+  cnt = PLR_T_IMP(PTab)->Kfg->TkCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Kfg->TokKind[i]);
+    fprintf(fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->TokKind[i],nl,suffix);
   }
   cnt = PLR_T_IMP(PTab)->Kfg->NtCnt;
-  fprintf(fp,"NtClass\n");
+  fprintf(fp,"%sNtClass%s%s\n",prefix,nl,suffix);
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Kfg->NtClass[i]);
+    fprintf(fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->NtClass[i],nl,suffix);
   }
-  fprintf(fp,"ErrorNt\n");
+  fprintf(fp,"%sErrorNt%s%s\n",prefix,nl,suffix);
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Kfg->ErrorNt[i]);
+    fprintf(fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Kfg->ErrorNt[i],nl,suffix);
   }
-  fprintf(fp,"\n# Productions\n\n");
+  fprintf
+  (
+    fp,"%s%s%s\n%s# Productions%s%s%s\n\n",prefix,nl,suffix,prefix,nl,nl,suffix
+  );
   cnt = PLR_T_IMP(PTab)->ProdCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"KFGPROD\n");
-    fprintf(fp,"pname=%s\n",PLR_T_IMP(PTab)->Prod[i].pname);
-    fprintf(fp,"method=%d\n",PLR_T_IMP(PTab)->Prod[i].method);
-    fprintf(fp,"id=%d\n",PLR_T_IMP(PTab)->Prod[i].id);
+    fprintf(fp,"%sKFGPROD%s%s\n",prefix,nl,suffix);
+    fprintf
+    (
+      fp,"%spname=%s%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].pname,nl,suffix
+    );
+    fprintf
+    (
+      fp,"%smethod=%d%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].method,nl,suffix
+    );
+    fprintf(fp,"%sid=%d%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].id,nl,suffix);
     scnt = PLR_T_IMP(PTab)->Prod[i].symcnt;
-    fprintf(fp,"symbols\n");
+    fprintf(fp,"%ssymbols%s%s\n",prefix,nl,suffix);
     for( j=0; j < scnt; ++j )
     {
-      fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Prod[i].symbols[j]);
+      fprintf
+      (
+        fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].symbols[j],nl,suffix
+      );
     }
-    fprintf(fp,"symfrms\n");
+    fprintf(fp,"%ssymfrms%s%s\n",prefix,nl,suffix);
     for( j=0; j < scnt; ++j )
     {
-      fprintf(fp,"%d\n",PLR_T_IMP(PTab)->Prod[i].symfrms[j]);
+      fprintf
+      (
+        fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].symfrms[j],nl,suffix
+      );
     }
   }
-  fprintf(fp,"\n# LALR(1) tables\n\n");
-  fprintf(fp,"MstShift\n");
+  fprintf
+  (
+    fp,"%s%s%s\n%s# LALR(1) tables%s%s%s\n\n",
+    prefix,nl,suffix,prefix,nl,nl,suffix
+  );
+  fprintf(fp,"%sMstShift%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.MstShiftCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.MstShift[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.MstShift[i],nl,suffix
+    );
   }
-  fprintf(fp,"DtlShift\n");
+  fprintf(fp,"%sDtlShift%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.DtlShiftCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.DtlShift[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.DtlShift[i],nl,suffix
+    );
   }
-  fprintf(fp,"GoTo\n");
+  fprintf(fp,"%sGoTo%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.GoToCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.GoTo[i]);
+    fprintf(fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.GoTo[i],nl,suffix);
   }
-  fprintf(fp,"GoToDft\n");
+  fprintf(fp,"%sGoToDft%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.GoToDftCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.GoToDft[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.GoToDft[i],nl,suffix
+    );
   }
-  fprintf(fp,"ActDft\n");
+  fprintf(fp,"%sActDft%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.ActDftCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.ActDft[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.ActDft[i],nl,suffix
+    );
   }
-  fprintf(fp,"ActExp\n");
+  fprintf(fp,"%sActExp%s%s\n",prefix,nl,suffix);
   cnt = PLR_T_IMP(PTab)->tabs.ActExpCnt;
   for( i=0; i < cnt; ++i )
   {
-    fprintf(fp,"%d\n",PLR_T_IMP(PTab)->tabs.ActExp[i]);
+    fprintf
+    (
+      fp,"%s%d%s%s\n",prefix,PLR_T_IMP(PTab)->tabs.ActExp[i],nl,suffix
+    );
   }
-  fprintf(fp,"\n");
+  fprintf(fp,"%s%s%s\n",prefix,nl,suffix);
 }
 
-void PLR_Src_Modul(string Environ, PLR_Tab PTab)
+void PLR_Src_Modul(string Environ, PLR_Tab PTab, string Template)
 #define PLR_printCTab PLR_CTab_Modul
-/* creates source [$'Environ'/]<Language>.ptbl for parse table 'PTab' */
+/* creates source [$'Environ'/]<Language>.ptbl for parse table 'PTab';
+   it uses the template file for the export, if 'Template' is a regular file 
+*/
 { FILE* fp; c_string fid;
 
   BUG_NULL(PTab); BUG_NULL(PLR_T_IMP(PTab)->Kfg);
   BUG_NULL(PLR_T_IMP(PTab)->Kfg->language);
   fid = Str_printf("%s.ptbl",PLR_T_IMP(PTab)->Kfg->language);
   fp = OpenPath(Environ,fid,"","wt");
-  PLR_Src_Source(fp,fid,PTab);
+  if( STR_EMPTY(Template) ) PLR_Src_Source(fp,fid,PTab,"","");
+  else
+  { FILE* pf = NULL; c_string line;
+    pf = OpnFile(Template,"rt");
+    while( (line=Line_get(pf)) != (c_string)NULL )
+    { c_string prefix, suffix;
+      if( Line_split(line,"@TABLE@",&prefix,&suffix) )
+      {
+        fprintf
+        (
+          fp,"%sptbl%s%s\n",
+          prefix?prefix:"",PLR_T_IMP(PTab)->Kfg->language,suffix?suffix:""
+        );
+      }
+      else
+      if( Line_split(line,"@LINE@",&prefix,&suffix) )
+      {
+        if( prefix != (c_string)NULL && suffix != (c_string)NULL )
+          PLR_Src_Source(fp,fid,PTab,prefix,suffix);
+        else
+        if( prefix != (c_string)NULL )
+          PLR_Src_Source(fp,fid,PTab,prefix,"");
+        else
+        if( suffix != (c_string)NULL )
+          PLR_Src_Source(fp,fid,PTab,"",suffix);
+        else
+          PLR_Src_Source(fp,fid,PTab,"","");
+      }
+      else fprintf(fp,"%s\n",line);
+      if( prefix != (c_string)NULL ) FreeMem(prefix);
+      if( suffix != (c_string)NULL ) FreeMem(suffix);
+      FreeMem(line);
+    }
+    fclose(pf);
+  }
   fclose(fp);
   FreeMem(fid);
 }
