@@ -341,7 +341,7 @@ static void Tok_quotient_backbuf(Scn_Stream_IMP s, long cBackLen)
 static void Tok_skip(Scn_Stream_IMP s)
 /* skip current cC ==> track position, get next cC */
 {
-  while( MAP_defined(s->cCSkip,s->cC) )
+  while( MAP_defined(s->cCSkip,(long)s->cC) )
   {
     if (s->cC == (( s->wc2mb == (string (*)(wc_string wc))NULL ) 
         ? (int)'\n' : WCHAR_LITERAL('\n')))
