@@ -197,7 +197,10 @@ namespace styx
   {
     if( pos >= (long int)txt.length() )
       return 0;
-    return (int)((txt[pos++])&0xff);
+    if( sizeof(TC) == sizeof(char) )
+      return (int)((txt[pos++])&0xff);
+    else
+      return (int)((txt[pos++])&0xffffffff);
   }
   
   template <class TC>
