@@ -461,6 +461,9 @@ static void checkListProds(PrsGen_T* PrsGen, int ntclass)
   { int nti = OT_GET(int,NTEQUIV(ntclass),i), j;
     for( j =  FIRSTNTPROD(NTSYMBOL(nti)); j <= LASTNTPROD(NTSYMBOL(nti)); ++j )
     { KFGPROD* prod = &PrsGen->ProdTab[j];
+/*
+printf("%s.%s.%s\n",PrsGen->Kfg->SNames[NTSYMBOL(ntclass)],PrsGen->Kfg->SNames[prod->id],prod->pname);
+*/
       if( nilProd(prod->pname) || consProd(prod->pname) ) isList = True;
       else
         if( ! ignProd(prod->pname) ) isOther = True;
@@ -958,9 +961,9 @@ static void Sprung(PrsGen_T* PrsGen, OL_Lst Von)
     int idx = PRODUCTION(curr) - 1, pos = POSITION(curr) - 1;
 
     if( pos != PrsGen->MaxSymCnt )
-    {
+    { INT dmy = 0;
       Nach = GET_KLIST(PrsGen->GoToKern,PrsGen->ProdTab[idx].symbols[pos]);
-      INSS_INTLE(nextProdElement(PrsGen,curr),Nach);
+      dmy = INSS_INTLE(nextProdElement(PrsGen,curr),Nach);
     }
   }
   for( i=0; i < NONTERMCNT; ++i )
@@ -970,9 +973,9 @@ static void Sprung(PrsGen_T* PrsGen, OL_Lst Von)
       for( j = FIRSTNTPROD(NTSYMBOL(i)); j <= LASTNTPROD(NTSYMBOL(i)); ++j )
       {
         if( PrsGen->ProdTab[j].symcnt )
-        {
+        { INT dmy = 0;
           Nach = GET_KLIST(PrsGen->GoToKern,PrsGen->ProdTab[j].symbols[0]);
-          INSS_INTLE(nextProdElement(PrsGen,KERNELEMENT(j,1)),Nach);
+          dmy = INSS_INTLE(nextProdElement(PrsGen,KERNELEMENT(j,1)),Nach);
         }
       }
     }
@@ -995,14 +998,14 @@ static void setLambdaProdElements(PrsGen_T* PrsGen, PSTATE* curr)
 
           if( ! pos || element != CURR_INTLE(curr->kern) )
           { BS_Set lahead = BS_create(TERMCNT);
-
+            INT dmy = 0;
             if( ! pos )
             {
-              INST_INTLE(element,curr->kern); INS_LOOK(lahead,curr->looks);
+              dmy = INST_INTLE(element,curr->kern); INS_LOOK(lahead,curr->looks);
             }
             else
             {
-              INSC_INTLE(element,curr->kern); INSN_LOOK(lahead,curr->looks,pos);
+              dmy = INSC_INTLE(element,curr->kern); INSN_LOOK(lahead,curr->looks,pos);
             }
           }
         }
@@ -1018,6 +1021,7 @@ static void setInitialStates(PrsGen_T* PrsGen)
   for( i=0; i < PrsGen->Kfg->StartCnt; ++i )
   { INT element = KERNELEMENT(PrsGen->ProdCnt-PrsGen->Kfg->StartCnt+i,1);
     BS_Set lahead = BS_create(TERMCNT);
+    INT dmy = 0;
 
     newState.symbol = -1;
     newState.looks  = NEW_LOOKTAB;
@@ -1025,7 +1029,7 @@ static void setInitialStates(PrsGen_T* PrsGen)
     INS_LOOK(lahead, newState.looks);
     newState.kern   = NEW_INTLIST;
     newState.states = NEW_INTLIST;
-    INST_INTLE(element, newState.kern);
+    dmy = INST_INTLE(element, newState.kern);
     INS_STATE(&newState,PrsGen->StateTab);
   }
 }
@@ -1038,11 +1042,12 @@ static bool existsFollowState(PrsGen_T* PrsGen, PSTATE* curr, OL_Lst newKLst)
   {
     if( OL_EQUAL(GET_STATE(PrsGen->StateTab,i)->kern,newKLst) )
     { INT pos = FND_INTLE(i,curr->states);
-
-      if( ! pos ) INST_INTLE(i,curr->states);
+      INT dmy = 0;
+      if( ! pos ) dmy = INST_INTLE(i,curr->states);
       else
       {
-        if( i != CURR_INTLE(curr->states) ) INSC_INTLE(i,curr->states);
+        if( i != CURR_INTLE(curr->states) ) 
+          dmy = INSC_INTLE(i,curr->states);
       }
       return( True );
     }
@@ -1065,6 +1070,7 @@ static void setStates(PrsGen_T* PrsGen)
       {
         if( ! existsFollowState(PrsGen,curr,GET_KLIST(PrsGen->GoToKern,j)) )
         { INT StateId, k;
+          INT dmy = 0;
 
           newState.symbol = j;
           newState.looks  = NEW_LOOKTAB;
@@ -1079,7 +1085,7 @@ static void setStates(PrsGen_T* PrsGen)
           }
           INS_STATE(&newState,PrsGen->StateTab);
           StateId = OT_CNT(PrsGen->StateTab) - 1;
-          INST_INTLE(StateId,curr->states);
+          dmy = INST_INTLE(StateId,curr->states);
           if( isNonTerm(PrsGen,j) ) 
             INS_INTTE((int)StateId,PrsGen->NonTermTab[NTIDX(j)].states);
         }
@@ -1905,6 +1911,7 @@ int PLR_addSN(PLR_Cfg Cfg, string StartNt)
 int PLR_addST(PLR_Cfg Cfg, string SpecTk)
 /* marks 'SpecTk' as special comment token */
 { INT tk, tki; int kind;
+  INT dmy = 0;
 
   BUG_NULL(Cfg); BUG_NULL(SpecTk);
   BUG_VNEQ(PLR_C_IMP(Cfg)->TkIdx,(OT_Tab)NULL);
@@ -1920,7 +1927,7 @@ int PLR_addST(PLR_Cfg Cfg, string SpecTk)
   }
   assert0(!CFG_KEY(kind),"illegal comment type");
   kind = CFG_TERM_TO_COM(kind);
-  UPD_INTTE(kind,PLR_C_IMP(Cfg)->TokKind,tk);
+  dmy = UPD_INTTE(kind,PLR_C_IMP(Cfg)->TokKind,tk);
   return tk;
 }
 
@@ -2071,6 +2078,7 @@ static PLR_Tab PLR_createTab_aux
     printNtClasses(&PrsGen);
   }
   else countConflicts(&PrsGen);
+  ((PARSETAB*)PTab)->Conflicts = PrsGen.conflictCnt;
   if( PrsGen.conflictCnt )
   {
     sprintf(buf,"%d conflicts. Use -diagnose !\n",PrsGen.conflictCnt);
